summaryrefslogtreecommitdiffstats
path: root/juk/mediafiles.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/mediafiles.h')
-rw-r--r--juk/mediafiles.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/juk/mediafiles.h b/juk/mediafiles.h
index ea6a4345..342739e7 100644
--- a/juk/mediafiles.h
+++ b/juk/mediafiles.h
@@ -24,15 +24,15 @@
namespace MediaFiles
{
/**
* Creates a JuK specific KFileDialog with the specified tqparent.
*/
- TQStringList openDialog(TQWidget *tqparent = 0);
+ TQStringList openDialog(TQWidget *parent = 0);
/**
* Creates a JuK specific KFileDialog for saving a playlist with the name
* playlistName and the specified tqparent and returns the file name.
*/
- TQString savePlaylistDialog(const TQString &playlistName, TQWidget *tqparent = 0);
+ TQString savePlaylistDialog(const TQString &playlistName, TQWidget *parent = 0);
/**
* Returns true if fileName is a supported media file.
@@ -24,15 +24,15 @@
{
/**
- * Creates a JuK specific KFileDialog with the specified tqparent.
+ * Creates a JuK specific KFileDialog with the specified parent.
*/
@@ -24,15 +24,15 @@
/**
* Creates a JuK specific KFileDialog for saving a playlist with the name
- * playlistName and the specified tqparent and returns the file name.
+ * playlistName and the specified parent and returns the file name.
*/